@echo off
@rem ----------------------------------------------------------------------------------------------------------
@rem This will migrate a previous embedded WAS express to the new embedded WAS express.
@rem 
@rem Pre-condition: The previous version of WAS should still be installed and the webadmin WAR file should still
@rem                be deployed. 
@rem                The new embedded WAS must already be installed.
@rem                The new Webadmin must already be installed.
@rem ----------------------------------------------------------------------------------------------------------
@setlocal


@rem Parse the parameters
:parseParams
if "%1" == "" goto :checkVars
if /I "%1" == "-s" set APPSRV_PREV_INSTALLROOT=%2& goto goodParam
if /I "%1" == "-t" set APPSRV_INSTALLROOT=%2& goto goodParam
if /I "%1" == "-l" set LDAP_TEMP_INSTALLFILES=%2& goto goodParam
if /I "%1" == "-i" set LDAP_INSTALLHOME=%2& goto goodParam
if /I "%1" == "-v" goto version
if /I "%1" == "-usage" goto usage
if /I "%1" == "-?" goto usage
goto usageBadParam

:goodParam
shift
shift
goto parseParams

:checkVars
if not defined APPSRV_PREV_INSTALLROOT goto usage
if not defined APPSRV_INSTALLROOT goto usage
if not defined LDAP_TEMP_INSTALLFILES goto usage
if not defined LDAP_INSTALLHOME goto usage

:checkPreviousDir
if not exist "%APPSRV_PREV_INSTALLROOT:"=%" goto errPrevDirMiss


:checkLdapHomeDir
if not exist "%LDAP_INSTALLHOME:"=%" goto errLdapHomeDirMiss


@rem appsrv save directory for this release
set APPSRV_SAVE=appsrv
@rem end appsrv save directory for this release

@rem ----------------------------------------------------------------------------------------------------------
@rem  Backup webadmin files from previous release 
@rem ----------------------------------------------------------------------------------------------------------
@rem war file dir
set PREV_APPSRV_WEBADMIN_PATH="%APPSRV_PREV_INSTALLROOT:"=%\installedApps\DefaultNode\IDSWebApp.war.ear\IDSWebApp.war\WEB-INF\classes"
if not exist "%LDAP_INSTALLHOME:"=%\etc" md "%LDAP_INSTALLHOME:"=%\etc"
if not exist "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\" md "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\"
copy "%PREV_APPSRV_WEBADMIN_PATH:"=%\security\console_passwd" "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\"
copy "%PREV_APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSSessionConfig\IDSSessionMgmt.xml" "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\"
copy "%PREV_APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSServersConfig\IDSServersInfo.xml" "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\"
copy "%PREV_APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSAppReg\IDSAppReg.xml" "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\"

@rem ----------------------------------------------------------------------------------------------------------
@rem  uninstall war file from previous release. We need to do this since we know we do not want to use
@rem  this old war file. We plan to use the war file from the new release. We need to do this before WASPreUpgrade
@rem  is run, otherwise the pre-upgrade backs this up.
@rem -----------------------------------------------------------------------------------------------------------
@rem uninstall war file
call "%APPSRV_PREV_INSTALLROOT:"=%\bin\wsadmin.bat" -conntype NONE -c "$AdminApp uninstall IDSWebApp.war"
if not %errorlevel% == 0 goto wasErrUninstall

@rem ----------------------------------------------------------------------------------------------------------
@rem Stop the application server - if this fails we will assume it was not started and continue with migration
@rem ----------------------------------------------------------------------------------------------------------
call "%APPSRV_PREV_INSTALLROOT:"=%\bin\stopServer.bat" server1
@rem echo Return code from stopping previous Application server is: %ERRORLEVEL%

@rem ----------------------------------------------------------------------------------------------------------
@rem Migrate - preUpgrade - give temp dir followed by old install dir
@rem ----------------------------------------------------------------------------------------------------------
call "%APPSRV_INSTALLROOT:"=%\bin\WASPreUpgrade.bat" %LDAP_TEMP_INSTALLFILES% %APPSRV_PREV_INSTALLROOT%
if not %errorlevel% == 0 goto wasPreupgradeErr

@rem ----------------------------------------------------------------------------------------------------------
@rem Migrate - postUpgrade - give temp dir 
@rem ----------------------------------------------------------------------------------------------------------
call "%APPSRV_INSTALLROOT:"=%\bin\WASPostUpgrade.bat" %LDAP_TEMP_INSTALLFILES% -replacePorts true
if not %errorlevel% == 0 goto wasPostupgradeErr


@rem ----------------------------------------------------------------------------------------------------------
@rem Now copy the new war file into the new WAS directory
@rem ----------------------------------------------------------------------------------------------------------
if not exist "%APPSRV_INSTALLROOT:"=%\installableApps"  md "%APPSRV_INSTALLROOT:"=%\installableApps"
copy "%LDAP_INSTALLHOME:"=%\idstools\IDSWebApp.war" "%APPSRV_INSTALLROOT:"=%\installableApps"
if not %errorlevel% == 0 goto warCopyErr

@rem ----------------------------------------------------------------------------------------------------------
@rem Now install the new WAR file into the new Was product
@rem ----------------------------------------------------------------------------------------------------------
call "%APPSRV_INSTALLROOT:"=%\bin\wsadmin.bat" -conntype NONE -c "$AdminApp install {%APPSRV_INSTALLROOT:"=%/installableApps/IDSWebApp.war} {-configroot \"%APPSRV_INSTALLROOT:"=%/config\" -node DefaultNode -usedefaultbindings -nodeployejb -appname IDSWebApp.war -contextroot \"IDSWebApp\"}"
if not %errorlevel% == 0 goto wsadminErr

@rem ----------------------------------------------------------------------------------------------------------
@rem Restore the webadmin configuration files saved previously
@rem ----------------------------------------------------------------------------------------------------------
set APPSRV_WEBADMIN_PATH="%APPSRV_INSTALLROOT:"=%\installedApps\DefaultNode\IDSWebApp.war.ear\IDSWebApp.war\WEB-INF\classes"
copy "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\console_passwd" "%APPSRV_WEBADMIN_PATH:"=%\security\" 
copy "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\IDSSessionMgmt.xml" "%APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSSessionConfig\"
copy "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\IDSServersInfo.xml" "%APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSServersConfig\"
copy "%LDAP_INSTALLHOME:"=%\etc\%APPSRV_SAVE%\IDSAppReg.xml" "%APPSRV_WEBADMIN_PATH:"=%\IDSConfig\IDSAppReg\"
goto done

@rem ----------------------------------------------------------------------------------------------------------
@rem Usage and error routines follow
@rem ----------------------------------------------------------------------------------------------------------
:usage
set ERRORLEVEL=0
echo.
echo Usage:
echo   idswmigr.bat [-s -t -l -i] [-v]
echo where:
echo.
echo  required fields are:
echo   -s is the source location for the previous version of embedded WebSphere Express (version to be migrated)
echo   -t is the target location where the new embedded WebSphere Express has been installed
echo   -l is the location for temporary files
echo   -i home directory where the current version of IBM Tivoli Directory Server has been installed
echo.
echo  optional fields are:
echo   -v is the version   
echo.
goto done

:usageBadParam
set ERRORLEVEL=1
echo ERROR: The command line parameter, %1, is invalid.
echo Use -usage to see the available command line options
goto done

:errPrevDirMiss
set ERRORLEVEL=1
echo ERROR: The previous embedded WebSphere Application Server - Express directory does not exist.
echo Specify a valid directory.
goto done


:errLdapHomeDirMiss
set ERRORLEVEL=1
echo ERROR: The current IBM Tivoli Directory Server directory does not exist.
echo Specify a valid directory.
goto done

:wasErrUninstall
echo ERROR: The IDSWebApp.war uninstall failed. Migration cannot continue.
goto done

:wasPreupgradeErr
echo ERROR: The embedded WAS PreUpgrade failed. Migration cannot continue.
goto done

:waspostupgradeErr
echo ERROR: The embedded WAS PostUpgrade failed. Migration cannot continue.
goto done

:warCopyErr
echo ERROR: Error copying the IDSWebApp.war. Migration cannot continue.
goto done

:wsadminErr
echo ERROR: Error executing wsadmin command. Migration cannot continue.
goto done

:version
set ERRORLEVEL=0
echo.
echo IBM Tivoli Directory Server 6.0 migration for embedded WebSphere Application Server - Express
goto done

:done
echo returnCode %ERRORLEVEL%
set APPSRV_PREV_INSTALLROOT=
set APPSRV_INSTALLROOT=
set LDAP_TEMP_INSTALLFILES=
set LDAP_INSTALLHOME=
@endlocal
